@@ -16,8 +16,9 @@ class bcolors:
 
 def LPrint(*args,**kwargs):
     caller = getframeinfo(stack()[1][0])
-    if not kwargs:
-        kwargs['end']='\n'
+    if 'end' not in kwargs:
+        kwargs['end']='\n\n'
+    if 'printFunc' not in kwargs:
         kwargs['printFunc']=pprint
     if sys.version[0]=='3':
         for x in args:
@@ -25,7 +26,7 @@ def LPrint(*args,**kwargs):
         print ('--print info>>>',end='')
     else:
         print (str(args).decode('unicode_escape'),'--info>>>  ',end='')
-    print ('{}{}{},line--{},fn--{}\n{}'.
+    print ('{}{}{},line--{},fn--{}{}'.
         format( bcolors.OKBLUE,
                 os.path.basename(caller.filename),
                 bcolors.ENDC,
@@ -34,7 +35,7 @@ def LPrint(*args,**kwargs):
                 bcolors.ENDC),end=kwargs['end'])
 
 def test_LPrint():
-    LPrint ((u'你好',u'世界',{u'你好':u'世界'},(u'你好',u'世界')))
+    LPrint ((u'你好',u'世界',{u'你好':u'世界'},(u'你好',u'世界')),end='\n\n')
     #print (r"u'\u4e16\u754c',{u'\u4f60\u597d': u'\u4e16\u754c'}".decode('unicode_escape'))
     
 if __name__=='__main__':
